@@ -1,8 +1,6 @@
 from . import configuration
 from . import env as appmapenv
-from . import event
-from . import metadata
-from . import recording
+from . import event, importer, metadata, recorder
 from .py_version_check import check_py_version
 
 
@@ -10,8 +8,10 @@ def initialize(**kwargs):
     check_py_version()
     appmapenv.initialize(**kwargs)
     event.initialize()
-    recording.initialize()
-    configuration.initialize()  # needs to be initialized after recording
+    importer.initialize()
+    recorder.initialize()
+    configuration.initialize()  # needs to be initialized after recorder
     metadata.initialize()
 
+
 initialize()
