@@ -2,26 +2,26 @@
 Manage Configuration AppMap recorder for Python.
 """
 
-from functools import lru_cache
 import inspect
 import logging
-from os.path import realpath
-from pathlib import Path
 import re
 import sys
+from functools import lru_cache
+from os.path import realpath
+from pathlib import Path
 from textwrap import dedent
 
 import importlib_metadata
 import yaml
 from yaml.parser import ParserError
 
+from appmap._implementation.detect_enabled import DetectEnabled
+
+from ..labeling import presets as label_presets
 from . import utils
 from .env import Env
+from .importer import Filter, Importer
 from .instrument import instrument
-from .labels import LabelSet
-from ..labeling import presets as label_presets
-from .metadata import Metadata
-from .recording import Filter, FilterableCls, Recorder
 
 logger = logging.getLogger(__name__)
 
@@ -29,15 +29,16 @@ logger = logging.getLogger(__name__)
 def warn_config_missing(path):
     """Display a warning about missing config file in path."""
     name = path.resolve().parent.name
-    package = re.sub(r'\W', '.', name).lower()
+    package = re.sub(r"\W", ".", name).lower()
+
 
 def default_app_name(rootdir):
     rootdir = Path(rootdir)
-    if not (rootdir / '.git').exists():
+    if not (rootdir / ".git").exists():
         return rootdir.name
 
     git = utils.git(cwd=str(rootdir))
-    repo_root = git('rev-parse --show-toplevel')
+    repo_root = git("rev-parse --show-toplevel")
     return Path(repo_root).name
 
 
@@ -45,6 +46,7 @@ def default_app_name(rootdir):
 def _get_sys_prefix():
     return realpath(sys.prefix)
 
+
 def find_top_packages(rootdir):
     """
     Scan a directory tree for packages that should appear in the
@@ -101,22 +103,21 @@ def find_top_packages(rootdir):
     import os
 
     def excluded(dir):
-        excluded = dir == 'node_modules' or dir[0] == '.'
+        excluded = dir == "node_modules" or dir[0] == "."
         if excluded:
-            logger.debug('excluding dir %s', dir)
+            logger.debug("excluding dir %s", dir)
         return excluded
 
-
     sys_prefix = _get_sys_prefix()
 
-    for dir,dirs,files in os.walk(rootdir):
-        logger.debug('dir %s dirs %s', dir, dirs)
+    for dir, dirs, files in os.walk(rootdir):
+        logger.debug("dir %s dirs %s", dir, dirs)
         if realpath(dir) == sys_prefix:
-            logger.debug('skipping sys.prefix %s', sys_prefix)
+            logger.debug("skipping sys.prefix %s", sys_prefix)
             dirs.clear()
             continue
 
-        if '__init__.py' in files:
+        if "__init__.py" in files:
             packages.add(Path(dir).name)
             dirs.clear()
         else:
@@ -124,13 +125,15 @@ def find_top_packages(rootdir):
 
     return packages
 
+
 class Config:
-    """ Singleton Config class """
+    """Singleton Config class"""
+
     _instance = None
 
     def __new__(cls):
         if cls._instance is None:
-            logger.debug('Creating the Config object')
+            logger.debug("Creating the Config object")
             cls._instance = super(Config, cls).__new__(cls)
 
             cls._instance._initialized = False
@@ -153,40 +156,47 @@ class Config:
 
     @property
     def name(self):
-        return self._config['name']
+        return self._config["name"]
 
     @property
     def packages(self):
-        return self._config['packages']
+        return self._config["packages"]
 
     @property
     @lru_cache(maxsize=None)
     def labels(self):
-        """ The LabelSet defined in the configuration, plus any presets. """
+        """The LabelSet defined in the configuration, plus any presets."""
         labels = label_presets()
-        if 'labels' in self._config:
-            labels.append(self._config['labels'])
+        if "labels" in self._config:
+            labels.append(self._config["labels"])
         return labels
 
     @property
     def default(self):
+        return {"name": self.default_name, "packages": self.default_packages}
+
+    @property
+    def default_name(self):
         root_dir = Env.current.root_dir
-        return {
-            'name': default_app_name(root_dir),
-            'packages': [{'path': p} for p in find_top_packages(root_dir)],
-        }
+        return default_app_name(root_dir)
+
+    @property
+    def default_packages(self):
+        root_dir = Env.current.root_dir
+        return [{"path": p} for p in find_top_packages(root_dir)]
 
     def _load_config(self):
-        self._config = {'name': None, 'packages': []}
+        self._config = {"name": None, "packages": []}
 
         # Only use a default config if the user hasn't specified a
         # config.
-        env_config = Env.current.get("APPMAP_CONFIG")
-        use_default_config = not env_config
-        if use_default_config:
-            env_config = 'appmap.yml'
+        env_config_filename = Env.current.get("APPMAP_CONFIG")
 
-        path = Path(env_config).resolve()
+        use_default_config = not env_config_filename
+        if use_default_config:
+            env_config_filename = "appmap.yml"
+
+        path = Path(env_config_filename).resolve()
         if path.is_file():
             self.file_present = True
 
@@ -195,11 +205,20 @@ class Config:
             self.file_valid = False
             try:
                 self._config = yaml.safe_load(path.read_text())
+                if not self._config:
+                    # It parsed, but was (effectively) empty.
+                    self._config = self.default
+                else:
+                    # It parsed, make sure it has name and packages set.
+                    if not self._config.get("name", None):
+                        self._config["name"] = self.default_name
+                    if not self._config.get("packages", None):
+                        self._config["packages"] = self.default_packages
                 self.file_valid = True
                 Env.current.enabled = should_enable
             except ParserError:
                 pass
-            logger.info('config: %s', self._config)
+            logger.info("config: %s", self._config)
             return
 
         if not Env.current.enabled:
@@ -207,22 +226,40 @@ class Config:
 
         logger.warning(dedent(f'Config file "{path}" is missing.'))
         if use_default_config:
-            logger.warning(dedent(f'''
-This default configuration will be used:
+            logger.warning(
+                dedent(
+                    f"""
+It will be created with this configuration: 
 
 {yaml.dump(self.default)}
-            '''))
+            """
+                )
+            )
             self._config = self.default
+            self.write_config_file(path, self.default)
         else:
             # disable appmap and return a dummy config
             # so the errors don't accumulate
             Env.current.enabled = False
 
+    def write_config_file(self, filepath, config):
+        # HACK: don't scribble on the repo when testing
+        if DetectEnabled.is_appmap_repo():
+            return
+        basedir = filepath.parent
+        if not basedir.exists():
+            basedir.mkdir(parents=True, exist_ok=True)
+        with open(filepath, "w") as f:
+            f.write(yaml.dump(config, sort_keys=True))
+
+
 def startswith(prefix, sequence):
     """
     Check if a sequence starts with the prefix.
     """
-    return len(prefix) <= len(sequence) and all(a == b for a, b in zip(sequence, prefix))
+    return len(prefix) <= len(sequence) and all(
+        a == b for a, b in zip(sequence, prefix)
+    )
 
 
 class PathMatcher:
@@ -230,25 +267,25 @@ class PathMatcher:
         excludes = excludes or []
         self.prefix = []
         if prefix:
-            self.prefix = prefix.split('.')
-        self.excludes = [x.split('.') for x in excludes]
+            self.prefix = prefix.split(".")
+        self.excludes = [x.split(".") for x in excludes]
         self.shallow = shallow
 
     def matches(self, filterable):
-        fqname = name = filterable.fqname.split('.')
+        fqname = name = filterable.fqname.split(".")
         if startswith(self.prefix, name):
-            name = name[len(self.prefix):]
+            name = name[len(self.prefix) :]
             result = not any(startswith(x, name) for x in self.excludes)
         else:
             result = False
-        logger.debug('%r.matches(%r) -> %r', self, fqname, result)
+        logger.debug("%r.matches(%r) -> %r", self, fqname, result)
         return result
 
     def __repr__(self):
-        return 'PathMatcher(%r, %r, shallow=%r)' % (
-            '.'.join(self.prefix),
-            ['.'.join(ex) for ex in self.excludes],
-            self.shallow
+        return "PathMatcher(%r, %r, shallow=%r)" % (
+            ".".join(self.prefix),
+            [".".join(ex) for ex in self.excludes],
+            self.shallow,
         )
 
 
@@ -261,7 +298,9 @@ class DistMatcher(PathMatcher):
     def matches(self, filterable):
         try:
             obj = filterable.obj
-            logger.debug('%r.matches(%r): %s in %r', self, obj, inspect.getfile(obj), self.files)
+            logger.debug(
+                "%r.matches(%r): %s in %r", self, obj, inspect.getfile(obj), self.files
+            )
             if inspect.getfile(obj) not in self.files:
                 return False
         except TypeError:
@@ -270,11 +309,11 @@ class DistMatcher(PathMatcher):
         return super().matches(filterable)
 
     def __repr__(self):
-        return 'DistMatcher(%r, %r, %r, shallow=%r)' % (
+        return "DistMatcher(%r, %r, %r, shallow=%r)" % (
             self.dist,
-            '.'.join(self.prefix),
-            ['.'.join(ex) for ex in self.excludes],
-            self.shallow
+            ".".join(self.prefix),
+            [".".join(ex) for ex in self.excludes],
+            self.shallow,
         )
 
 
@@ -284,22 +323,24 @@ class MatcherFilter(Filter):
         self.matchers = matchers
 
     def filter(self, filterable):
-        result = any(m.matches(filterable) for m in self.matchers) or self.next_filter.filter(filterable)
-        logger.debug('ConfigFilter.filter(%r) -> %r', filterable.fqname, result)
+        result = any(
+            m.matches(filterable) for m in self.matchers
+        ) or self.next_filter.filter(filterable)
+        logger.debug("ConfigFilter.filter(%r) -> %r", filterable.fqname, result)
         return result
 
     def wrap(self, filterable):
         rule = self.match(filterable)
         if rule:
-            wrapped = getattr(filterable.obj, '_appmap_wrapped', None)
+            wrapped = getattr(filterable.obj, "_appmap_wrapped", None)
             if wrapped is None:
-                logger.debug('  wrapping %s', filterable.fqname)
+                logger.debug("  wrapping %s", filterable.fqname)
                 Config().labels.apply(filterable)
                 ret = instrument(filterable)
                 if rule.shallow:
-                    setattr(ret, '_appmap_shallow', rule)
+                    setattr(ret, "_appmap_shallow", rule)
             else:
-                logger.debug('  already wrapped %s', filterable.fqname)
+                logger.debug("  already wrapped %s", filterable.fqname)
                 ret = filterable.obj
             return ret
 
@@ -310,18 +351,18 @@ class MatcherFilter(Filter):
 
 
 def matcher_of_config(package):
-    dist = package.get('dist', None)
+    dist = package.get("dist", None)
     if dist:
         return DistMatcher(
             dist,
-            package.get('path', None),
-            package.get('exclude', []),
-            shallow=package.get('shallow', True)
+            package.get("path", None),
+            package.get("exclude", []),
+            shallow=package.get("shallow", True),
         )
     return PathMatcher(
-        package['path'],
-        package.get('exclude', []),
-        shallow=package.get('shallow', False)
+        package["path"],
+        package.get("exclude", []),
+        shallow=package.get("shallow", False),
     )
 
 
@@ -337,14 +378,15 @@ class BuiltinFilter(MatcherFilter):
     def __init__(self, *args, **kwargs):
         matchers = []
         if Env.current.enabled:
-            matchers = [PathMatcher(f) for f in {'os.read', 'os.write'}]
+            matchers = [PathMatcher(f) for f in {"os.read", "os.write"}]
         super().__init__(matchers, *args, **kwargs)
 
 
 def initialize():
+    DetectEnabled.initialize()
     Config().initialize()
-    Recorder().use_filter(BuiltinFilter)
-    Recorder().use_filter(ConfigFilter)
+    Importer.use_filter(BuiltinFilter)
+    Importer.use_filter(ConfigFilter)
 
 
 initialize()
