@@ -1,11 +1,10 @@
 import time
 
-from twisted.internet import defer
-from twisted.internet import reactor
+from twisted.internet import defer, reactor
 from twisted.trial import unittest
 
-class TestDeferred(unittest.TestCase):
 
+class TestDeferred(unittest.TestCase):
     def test_hello_world(self):
         d = defer.Deferred()
 
@@ -17,4 +16,5 @@ class TestDeferred(unittest.TestCase):
         reactor.callLater(1, d.callback, None)
 
         return d
+
     test_hello_world.todo = "don't fix me"
