@@ -1,17 +1,18 @@
-from distutils.dir_util import copy_tree
-import os
 import json
-from pathlib import Path
+import os
 import re
+from distutils.dir_util import copy_tree
+from pathlib import Path
 
-
-from importlib_metadata import version
 import pytest
+from importlib_metadata import version
 
 import appmap._implementation
 from appmap.command import appmap_agent_init, appmap_agent_status, appmap_agent_validate
+
 from .helpers import DictIncluding
 
+
 @pytest.fixture
 def cmd_setup(request, git, data_dir, monkeypatch):
     repo_root = git.cwd
@@ -23,6 +24,7 @@ def cmd_setup(request, git, data_dir, monkeypatch):
 
     return monkeypatch
 
+
 @pytest.mark.parametrize("cmd_setup", ["config"], indirect=True)
 def test_agent_init(cmd_setup, capsys):
     rc = appmap_agent_init._run()
@@ -33,8 +35,9 @@ def test_agent_init(cmd_setup, capsys):
     # Make sure the JSON has the correct form, and contains the
     # expected filename. The contents of the default appmap.yml are
     # verified by other tests
-    assert config['configuration']['filename'] == 'appmap.yml'
-    assert config['configuration']['contents'] is not None
+    assert config["configuration"]["filename"] == "appmap.yml"
+    assert config["configuration"]["contents"] is not None
+
 
 class TestAgentStatus:
     @pytest.mark.parametrize("cmd_setup", ["pytest"], indirect=True)
@@ -46,7 +49,6 @@ class TestAgentStatus:
         call_count = 1 if do_discovery else 0
         assert appmap_agent_status.discover_pytest_tests.call_count == call_count
 
-
     @pytest.mark.parametrize("cmd_setup", ["pytest"], indirect=True)
     def test_agent_status(self, cmd_setup, capsys):
         rc = appmap_agent_status._run(discover_tests=True)
@@ -56,28 +58,27 @@ class TestAgentStatus:
         # XXX This will detect pytest as the test framework, because
         # appmap-python uses it. We need a better mechanism to handle
         # testing more broadly.
-        assert status == DictIncluding({
-            "properties": {
-                "config": {
-                    "app": "Simple",
-                    "present": True,
-                    "valid": True
+        assert status == DictIncluding(
+            {
+                "properties": {
+                    "config": {"app": "Simple", "present": True, "valid": True},
+                    "project": {
+                        "agentVersion": "0.0.0",
+                        "language": "python",
+                        "remoteRecordingCapable": True,
+                        "integrationTests": True,
+                    },
                 },
-            "project": {
-                "agentVersion": "0.0.0",
-                "language": "python",
-                "remoteRecordingCapable": True,
-                "integrationTests": True
+                "test_commands": [
+                    {
+                        "args": [],
+                        "framework": "pytest",
+                        "command": "pytest",
+                        "environment": {"APPMAP": "true"},
+                    }
+                ],
             }
-            },
-            "test_commands": [{
-                "args": [],
-                "framework": "pytest",
-                "command": "pytest",
-                "environment": {
-                    "APPMAP": "true"
-                }
-            }]})
+        )
 
     @pytest.mark.parametrize("cmd_setup", ["package1"], indirect=True)
     def test_agent_status(self, cmd_setup, capsys):
@@ -86,7 +87,8 @@ class TestAgentStatus:
         output = capsys.readouterr()
         status = json.loads(output.out)
 
-        assert 'test_commands' not in status
+        assert "test_commands" not in status
+
 
 class TestAgentValidate:
     def check_errors(self, capsys, status, count, msg):
@@ -99,31 +101,40 @@ class TestAgentValidate:
         assert len(errors) == count
         if count > 0:
             err = errors[0]
-            assert err['level'] == 'error'
-            assert re.match(msg , err['message']) != None
-
+            assert err["level"] == "error"
+            assert re.match(msg, err["message"]) != None
 
     def test_no_errors(self, capsys, mocker):
         # Both Django and flask are installed in a dev environment, so
         # validation will succeed.
         self.check_errors(capsys, 0, 0, None)
 
-
     def test_python_version(self, capsys, mocker):
-        mocker.patch('appmap._implementation.py_version_check._get_py_version', return_value=(3,5))
-        mocker.patch('appmap._implementation.py_version_check._get_platform_version', return_value='3.5')
+        mocker.patch(
+            "appmap._implementation.py_version_check._get_py_version",
+            return_value=(3, 5),
+        )
+        mocker.patch(
+            "appmap._implementation.py_version_check._get_platform_version",
+            return_value="3.5",
+        )
 
-        self.check_errors(capsys, 1, 1, r'Minimum Python version supported is \d\.\d, found')
+        self.check_errors(
+            capsys, 1, 1, r"Minimum Python version supported is \d\.\d, found"
+        )
 
     def test_django_version(self, capsys, mocker):
-        m = mocker.patch('appmap.command.appmap_agent_validate.version',
-                         side_effect=lambda d:  '3.1' if d == 'django' else version(d))
-
-        self.check_errors(capsys, 1, 1, 'django must have version >= 3.2, found 3.1')
+        m = mocker.patch(
+            "appmap.command.appmap_agent_validate.version",
+            side_effect=lambda d: "3.1" if d == "django" else version(d),
+        )
 
+        self.check_errors(capsys, 1, 1, "django must have version >= 3.2, found 3.1")
 
     def test_flask_version(self, capsys, mocker):
-        m = mocker.patch('appmap.command.appmap_agent_validate.version',
-                         side_effect=lambda d:  '1.0' if d == 'flask' else version(d))
+        m = mocker.patch(
+            "appmap.command.appmap_agent_validate.version",
+            side_effect=lambda d: "1.0" if d == "flask" else version(d),
+        )
 
-        self.check_errors(capsys, 1, 1,  'flask must have version >= 1.1, found 1.0')
+        self.check_errors(capsys, 1, 1, "flask must have version >= 1.1, found 1.0")
